@@ -31,7 +31,7 @@ var __extends = (this && this.__extends) || (function () {
 var C = /** @class */ (function (_super) {
     __extends(C, _super);
     function C() {
-        _this = _super.call(this) || this;
+        var _this = _super.call(this) || this;
         return Object.create(null);
     }
     return C;
