@@ -27,7 +27,13 @@ Output::
 >> Screen clear
 [[90m12:00:15 AM[0m] Starting compilation in watch mode...
 
-[[90m12:00:18 AM[0m] Found 0 errors. Watching for file changes.
+[96ma/tsconfig.json[0m:[93m1[0m:[93m21[0m - [91merror[0m[90m TS5101: [0mOption 'out' is deprecated and will stop functioning in TypeScript 5.5. Specify compilerOption '"ignoreDeprecations": "5.0"' to silence this error.
+  Use 'outFile' instead.
+
+[7m1[0m {"compilerOptions":{"out":"/a/out.js"}}
+[7m [0m [91m                    ~~~~~[0m
+
+[[90m12:00:18 AM[0m] Found 1 error. Watching for file changes.
 
 
 
@@ -43,23 +49,23 @@ No cached semantic diagnostics in the builder::
 
 No shapes updated in the builder::
 
-WatchedFiles::
-/a/tsconfig.json:
-  {"fileName":"/a/tsconfig.json","pollingInterval":250}
-/a/a.ts:
-  {"fileName":"/a/a.ts","pollingInterval":250}
-/a/b.ts:
-  {"fileName":"/a/b.ts","pollingInterval":250}
-/a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+PolledWatches::
 /a/node_modules/@types:
-  {"fileName":"/a/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
+/a/tsconfig.json:
+  {}
+/a/a.ts:
+  {}
+/a/b.ts:
+  {}
+/a/lib/lib.d.ts:
+  {}
 
 FsWatchesRecursive::
 /a:
-  {"directoryName":"/a"}
+  {}
 
 exitCode:: ExitStatus.undefined
 
@@ -80,7 +86,13 @@ Output::
 >> Screen clear
 [[90m12:00:22 AM[0m] File change detected. Starting incremental compilation...
 
-[[90m12:00:26 AM[0m] Found 0 errors. Watching for file changes.
+[96ma/tsconfig.json[0m:[93m1[0m:[93m21[0m - [91merror[0m[90m TS5101: [0mOption 'out' is deprecated and will stop functioning in TypeScript 5.5. Specify compilerOption '"ignoreDeprecations": "5.0"' to silence this error.
+  Use 'outFile' instead.
+
+[7m1[0m {"compilerOptions":{"out":"/a/out.js"}}
+[7m [0m [91m                    ~~~~~[0m
+
+[[90m12:00:26 AM[0m] Found 1 error. Watching for file changes.
 
 
 
@@ -96,23 +108,23 @@ No cached semantic diagnostics in the builder::
 
 No shapes updated in the builder::
 
-WatchedFiles::
-/a/tsconfig.json:
-  {"fileName":"/a/tsconfig.json","pollingInterval":250}
-/a/a.ts:
-  {"fileName":"/a/a.ts","pollingInterval":250}
-/a/b.ts:
-  {"fileName":"/a/b.ts","pollingInterval":250}
-/a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+PolledWatches::
 /a/node_modules/@types:
-  {"fileName":"/a/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
+/a/tsconfig.json:
+  {}
+/a/a.ts:
+  {}
+/a/b.ts:
+  {}
+/a/lib/lib.d.ts:
+  {}
 
 FsWatchesRecursive::
 /a:
-  {"directoryName":"/a"}
+  {}
 
 exitCode:: ExitStatus.undefined
 
@@ -133,7 +145,13 @@ Output::
 >> Screen clear
 [[90m12:00:30 AM[0m] File change detected. Starting incremental compilation...
 
-[[90m12:00:34 AM[0m] Found 0 errors. Watching for file changes.
+[96ma/tsconfig.json[0m:[93m1[0m:[93m21[0m - [91merror[0m[90m TS5101: [0mOption 'out' is deprecated and will stop functioning in TypeScript 5.5. Specify compilerOption '"ignoreDeprecations": "5.0"' to silence this error.
+  Use 'outFile' instead.
+
+[7m1[0m {"compilerOptions":{"out":"/a/out.js"}}
+[7m [0m [91m                    ~~~~~[0m
+
+[[90m12:00:34 AM[0m] Found 1 error. Watching for file changes.
 
 
 
@@ -149,23 +167,23 @@ No cached semantic diagnostics in the builder::
 
 No shapes updated in the builder::
 
-WatchedFiles::
-/a/tsconfig.json:
-  {"fileName":"/a/tsconfig.json","pollingInterval":250}
-/a/a.ts:
-  {"fileName":"/a/a.ts","pollingInterval":250}
-/a/b.ts:
-  {"fileName":"/a/b.ts","pollingInterval":250}
-/a/lib/lib.d.ts:
-  {"fileName":"/a/lib/lib.d.ts","pollingInterval":250}
+PolledWatches::
 /a/node_modules/@types:
-  {"fileName":"/a/node_modules/@types","pollingInterval":500}
+  {"pollingInterval":500}
 
 FsWatches::
+/a/tsconfig.json:
+  {}
+/a/a.ts:
+  {}
+/a/b.ts:
+  {}
+/a/lib/lib.d.ts:
+  {}
 
 FsWatchesRecursive::
 /a:
-  {"directoryName":"/a"}
+  {}
 
 exitCode:: ExitStatus.undefined
 
