@@ -23,12 +23,7 @@ verify.completions({
     includes: [
         {
             name: "boo",
-            sortText: completion.SortText.LocationPriority,
-            replacementSpan: {
-                fileName: "",
-                pos: 0,
-                end: 0,
-            },
+            sortText: completion.SortText.ClassMemberSnippets,
             insertText: "boo(): string;",
         }
     ],
